@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 """
 pyweblib.forms - class library for handling <FORM> input
-(c) by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2015 by Michael Ströder <michael@stroeder.com>
 
 This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
@@ -10,11 +11,12 @@ Python compability note:
 This module only works with Python 2.0 since all string parameters
 are assumed to be Unicode objects and string methods are used instead
 string module.
-
-$Id: forms.py,v 1.49 2014/03/22 18:37:34 michael Exp $
 """
 
-__version__ = '0.16.0'
+# File specific
+__revision__ = '$Revision: 1.53 $'.split(' ')[1]
+__info__ = '$Id: forms.py,v 1.53 2015/01/10 14:37:17 michael Exp $'
+
 
 import sys,types,re,urllib
 import helper
@@ -52,7 +54,7 @@ class Field:
   ):
     """
     name
-        Field name used in <INPUT NAME="..">
+        Field name used in <input name="..">
     text
         User-friendly text describing this field
     maxLen
@@ -378,7 +380,7 @@ class File(Input):
 class Password(Input):
   """
   Password input field:
-  <input type=password>
+  <input type="password">
   """
 
   def inputHTML(self,default=None,id_value=None,title=None):
@@ -405,7 +407,7 @@ class Password(Input):
 class Radio(Field):
   """
   Radio buttons:
-  <INPUT TYPE=RADIO>
+  <input type="radio">
   """
 
   def __init__(
@@ -581,7 +583,7 @@ class Select(Radio):
 class Checkbox(Field):
   """
   Check boxes:
-  <INPUT TYPE=CHECKBOX>
+  <input type="checkbox">
   """
 
   def __init__(
